/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log.Writer
{
    using System;
    using System.Collections.Generic;
    using System.Data;

    /// <summary>
    /// The persistor is an object that provides features to access the log database to query it
    /// </summary>
    public interface IPersistor
    {
        #region Properties

        /// <summary>
        /// Gets or sets the arguments of the stored procedure.
        /// </summary>
        /// <value>The arguments.</value>
        Dictionary<string, string> Arguments
        {
            get;
        }

        /// <summary>
        /// Gets the query.
        /// </summary>
        /// <value>The query.</value>
        string Query
        {
            get;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Executes assembly SQL query that does not return rows.
        /// Execute an UPDATE, DELETE or INSERT.
        /// </summary>
        /// <returns>
        /// 	<c>true</c> if the operation succeed. Otherwise <c>false</c>
        /// </returns>
        bool ExecuteNonQuery();

        /// <summary>
        /// Executes assembly SELECT query against the database.
        /// </summary>
        /// <returns>DataSet with the result of the query</returns>
        DataSet ExecuteQuery();

        /// <summary>
        /// Execute the command and return the first column of the first row of the resultset
        /// (if present), or null if no resultset was returned.
        /// </summary>
        /// <returns>The first column of the first row of the first resultset from the query.</returns>
        object ExecuteScalar();

        /// <summary>
        /// Loads the specified stored procedure name.
        /// </summary>
        /// <param name="storedProcedureName">Name of the stored procedure.</param>
        /// <returns>
        /// 	<c>true</c> if the stored procedure was found. Otherwise <c>false</c>
        /// </returns>
        bool LoadStoredProcedure(string storedProcedureName);

        #endregion Methods
    }
}